/*! \file file_io.cpp
 *
 * \brief Implementation of file I/O operations.
 */
#include <string>
#include "hdf5.h"

#ifndef INCLUDE_FILE_IO_H_
#include "../include/file_io.h"
#endif

using namespace std;

FileSchema::FileSchema(int num_rec, string *rec_types) {
  num_records = num_rec;
  record_types = new string[num_rec];
  for (int i = 0; i < num_rec; i++) record_types[i] = rec_types[i];
}

FileSchema::~FileSchema() { delete[] record_types; }

HDFFile::HDFFile(string name, unsigned int flags, hid_t fcpl_id, hid_t fapl_id) {
  file_name = name;
  file_id = H5Fcreate(name.c_str(), flags, fcpl_id, fapl_id);
  if (file_id != H5I_INVALID_HID) file_open_flag = true;
  status = (herr_t)0;
}

herr_t HDFFile::close() {
  status = H5Fclose(file_id);
  if (status == 0) file_open_flag = false;
  return status;
}
